#include <stdio.h>
#include <conio.h>
#include <windows.h>
#include "USB-ADIO.h"

int main()
	{
	// define the port number:
	unsigned short PortNum = 0;

	// open the port, attach it to COM1:
	if (USB_ADIO_Open (PortNum, 1))
		{
		printf ("%s\n", USB_ADIO_ErrorMessage (PortNum));
		return 1; // handle a possible error
		}

	printf ("Press 'i' to get identification data, "
		"or 'Esc' to stop\n");

	// Set automatic transmission of analog input voltage:
	if (USB_ADIO_AutoAnalogInput (PortNum, false))
		printf ("%s\n", USB_ADIO_ErrorMessage (PortNum));

	// Set automatic transmission of digital input state:
	if (USB_ADIO_AutoDigitalInput (PortNum))
		printf ("%s\n", USB_ADIO_ErrorMessage (PortNum));

	// main program loop:
	while (true)
		{
		WORD Mask;
		// check for data:
		const int Result = USB_ADIO_CheckAutoInput (PortNum, Mask);

		if (Result < 0) // handle a possible error
			printf ("%s\n", USB_ADIO_ErrorMessage (PortNum));

		if (Result == 0) // automatic data ready?
			{
			if (Mask & USB_ADIO_AUTO_AIN)
				{
				float Volt = 0;
				if (USB_ADIO_GetLastAnalogInput (PortNum, false, Volt))
					printf ("%s\n", USB_ADIO_ErrorMessage (PortNum));
				else
					printf ("Analog input: %.3fV\n", Volt);
				}
			if (Mask & USB_ADIO_AUTO_DIN)
				{
				WORD Data = 0;
				if (USB_ADIO_GetLastDigitalInput (PortNum, Data))
					printf ("%s\n", USB_ADIO_ErrorMessage (PortNum));
				else
					printf ("Digital input: %d (%02Xh)\n",
						Data, Data);
				}
			}

		if (kbhit() == 0) continue; // repeat if no key is pressed
		const int Key = getch();    // read the pressed key

		// get identification data:
		if (Key == 'i')
			{
			// get firmware version:
			WORD Version;
			if (USB_ADIO_FW_Ver (PortNum, Version))
				printf ("%s\n", USB_ADIO_ErrorMessage (PortNum));
			else
				printf ("Firmware version: %d.%02d\n",
					Version / 0x100, Version & 0xFF);

			// get firmware date:
			char DateString [20];
			if (USB_ADIO_FW_Date (PortNum, DateString))
				printf ("%s\n", USB_ADIO_ErrorMessage (PortNum));
			else
				printf ("Firmware date: %s\n", DateString);

			// get product identification:
			char IDString [20];
			if (USB_ADIO_prod_ID (PortNum, IDString))
				printf ("%s\n", USB_ADIO_ErrorMessage (PortNum));
			else
				printf ("Product identification: %s\n", IDString);

			// get product number:
			DWORD Number;
			if (USB_ADIO_prod_No (PortNum, Number))
				printf ("%s\n", USB_ADIO_ErrorMessage (PortNum));
			else
				printf ("Product number: %d\n", Number);
			}

		// stop on 'Esc':
		if (Key == 27)
			break;
		}

	//finish the program:
	return 0;
	}
